'''
探针包地址，最终兜底逻辑。一旦设置只会走该地址下载。
'''
import os

PYTHON_AGENT_PATH = "PYTHON_AGENT_PATH"
'''
区域，拉去对应region的探针包
'''
REGION_ID = "ARMS_REGION_ID"
'''
探针版本
'''
VERSION = "VERSION"
'''
内网后缀
'''
INTERNAL = "-internal"
'''
oss地址后缀
'''
OSS_URL = "aliyuncs.com"
'''
oss bucket 列表
'''
OSS_BUCKET_LIST = {
    "cn-shanghai-finance-1": "arms-apm-cn-shanghai-finance-1",
    "cn-qingdao": "arms-apm-cn-qingdao",
    "cn-hongkong": "arms-apm-cn-hongkong",
    "cn-beijing": "arms-apm-cn-beijing",
    "cn-zhangjiakou": "arms-apm-cn-zhangjiakou",
    "cn-huhehaote": "arms-apm-cn-huhehaote",
    "cn-wulanchabu": "arms-apm-cn-wulanchabu",
    "cn-heyuan": "arms-apm-cn-heyuan",
    "cn-guangzhou": "arms-apm-cn-guangzhou",
    "cn-chengdu": "arms-apm-cn-chengdu",
    "cn-hangzhou": "arms-apm-cn-hangzhou",
    "cn-shanghai": "arms-apm-cn-shanghai",
    "cn-shenzhen": "arms-apm-cn-shenzhen",
    "ap-southeast-2": "arms-apm-ap-southeast-2",
    "ap-southeast-3": "arms-apm-ap-southeast-3",
    "me-east-1": "arms-apm-me-east-1",
    "us-east-1": "arms-apm-us-east-1",
    "ap-south-1": "arms-apm-ap-south-1",
    "ap-northeast-1": "arms-apm-ap-northeast-1",
    "ap-southeast-1": "arms-apm-ap-southeast-1",
    "us-west-1": "arms-apm-us-west-1",
    "eu-west-1": "arms-apm-eu-west-1",
    "eu-central-1": "arms-apm-eu-central-1",
    "ap-southeast-5": "arms-apm-ap-southeast-5",
    "cn-shenzhen-finance-1": "arms-apm-cn-shenzhen-finance-1",
    "cn-hangzhou-finance": "arms-apm-cn-hangzhou-finance",
    "cn-north-2-gov-1": "arms-apm-cn-north-2-gov-1",
    "ap-southeast-6": "arms-apm-ap-southeast-6",
    "me-central-1": "arms-apm-me-central-1",
    "ap-southeast-7": "arms-apm-ap-southeast-7",
    "cn-zhengzhou-jva": "arms-apm-cn-zhengzhou-jva"
}
'''
oss prefix
'''
OSS_PREFIX = {
    "cn-shanghai-finance-1": "oss-cn-shanghai-finance-1",
    "cn-qingdao": "oss-cn-qingdao",
    "cn-hongkong": "oss-cn-hongkong",
    "cn-beijing": "oss-cn-beijing",
    "cn-zhangjiakou": "oss-cn-zhangjiakou",
    "cn-huhehaote": "oss-cn-huhehaote",
    "cn-wulanchabu": "oss-cn-wulanchabu",
    "cn-heyuan": "oss-cn-heyuan",
    "cn-guangzhou": "oss-cn-guangzhou",
    "cn-chengdu": "oss-cn-chengdu",
    "cn-hangzhou": "oss-cn-hangzhou",
    "cn-shanghai": "oss-cn-shanghai",
    "cn-shenzhen": "oss-cn-shenzhen",
    "ap-southeast-2": "oss-ap-southeast-2",
    "ap-southeast-3": "oss-ap-southeast-3",
    "me-east-1": "oss-me-east-1",
    "us-east-1": "oss-us-east-1",
    "ap-south-1": "oss-ap-south-1",
    "ap-northeast-1": "oss-ap-northeast-1",
    "ap-southeast-1": "oss-ap-southeast-1",
    "us-west-1": "oss-us-west-1",
    "eu-west-1": "oss-eu-west-1",
    "eu-central-1": "oss-eu-central-1",
    "ap-southeast-5": "oss-ap-southeast-5",
    "eu-central-1": "oss-eu-central-1",
    "cn-shanghai-finance-1": "oss-cn-shanghai-finance-1",
    "cn-shenzhen-finance-1": "oss-cn-shenzhen-finance-1",
    "cn-hangzhou-finance": "oss-cn-hzjbp-a",
    "cn-north-2-gov-1": "oss-cn-north-2-gov-1",
    "cn-shenzhen-finance-1": "oss-cn-shenzhen-finance-1",
    "cn-qingdao": "oss-cn-qingdao",
    "cn-north-2-gov-1": "oss-cn-north-2-gov-1",
    "ap-southeast-6": "oss-ap-southeast-6",
    "me-central-1": "oss-me-central-1",
    "ap-southeast-7": "oss-ap-southeast-7",
    "cn-zhengzhou-jva": "oss-cn-zhengzhou-jva",
}

'''
控制是否使用公网的参数，做应急使用。一般不透出
正常使用auto自动判断即可
'''
PROFILER_NETWORK_STRATEGY = "PROFILER_NETWORK_STRATEGY"

'''
oss path
'''
OSS_PATH = "aliyun-python-agent"
'''
agent文件名
'''
AGENT_FILE_NAME = "aliyun-python-agent.tar.gz"
'''
默认探针地址
'''
DEFAULT_AGENT_URL = "https://arms-apm-cn-hangzhou.oss-cn-hangzhou.aliyuncs.com/aliyun-python-agent/aliyun-python-agent.tar.gz"



import os
from aliyun.bootstrap import envs
import logging
import requests

logger = logging.getLogger(__name__)
'''
获取agent 下载地址。
'''


def get_agent_path():
    url = os.getenv(envs.PYTHON_AGENT_PATH, None)
    if url is not None:
        return url
    region_id = os.getenv(envs.REGION_ID, None)
    if region_id is None:
        return None
    bucket_name = envs.OSS_BUCKET_LIST[region_id]
    if bucket_name is None:
        return None
    oss_prefix = envs.OSS_PREFIX[region_id]
    if oss_prefix is None:
        return None

    # Check if version is specified
    version = os.getenv("VERSION", None)
    if version:
        # Use version-specific path
        path_segment = f"{envs.OSS_PATH}/{version}/{envs.AGENT_FILE_NAME}"
    else:
        # Use default path
        path_segment = f"{envs.OSS_PATH}/{envs.AGENT_FILE_NAME}"

    # Try internal URL first
    url = f"https://{bucket_name}.{oss_prefix}{envs.INTERNAL}.{envs.OSS_URL}/{path_segment}"
    internal_connect = check_network(url=url)
    if internal_connect:
        logger.info(f"use internal region url {url}")
        return url
        
    # Fallback to public URL
    url = f"https://{bucket_name}.{oss_prefix}.{envs.OSS_URL}/{path_segment}"
    public_connect = check_network(url=url)
    if public_connect:
        logger.info(f"use public region url {url}")
        return url
    return None


'''
判断网络是否通
'''


def check_network(url, timeout=1):
    try:
        response = requests.request("GET", url, timeout=timeout)
        if response.status_code == 200:
            return True
    except Exception:
        return False



# Copyright The Aliyun Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# DO NOT EDIT. THIS FILE WAS AUTOGENERATED FROM INSTRUMENTATION PACKAGES.
# RUN `python scripts/generate_instrumentation_bootstrap.py` TO REGENERATE.

libraries = [
    # {
    #     "library": "aio_pika >= 7.2.0, < 10.0.0",
    #     "instrumentation": "opentelemetry-instrumentation-aio-pika==0.46b0.dev",
    # },
    # {
    #     "library": "aiohttp ~= 3.0",
    #     "instrumentation": "opentelemetry-instrumentation-aiohttp-client==0.46b0.dev",
    # },
    # {
    #     "library": "aiohttp ~= 3.0",
    #     "instrumentation": "opentelemetry-instrumentation-aiohttp-server==0.46b0.dev",
    # },
    # {
    #     "library": "aiopg >= 0.13.0, < 2.0.0",
    #     "instrumentation": "opentelemetry-instrumentation-aiopg==0.46b0.dev",
    # },
    # {
    #     "library": "asgiref ~= 3.0",
    #     "instrumentation": "opentelemetry-instrumentation-asgi==0.46b0.dev",
    # },
    # {
    #     "library": "asyncpg >= 0.12.0",
    #     "instrumentation": "opentelemetry-instrumentation-asyncpg==0.46b0.dev",
    # },
    # {
    #     "library": "boto~=2.0",
    #     "instrumentation": "opentelemetry-instrumentation-boto==0.46b0.dev",
    # },
    # {
    #     "library": "boto3 ~= 1.0",
    #     "instrumentation": "opentelemetry-instrumentation-boto3sqs==0.46b0.dev",
    # },
    # {
    #     "library": "botocore ~= 1.0",
    #     "instrumentation": "opentelemetry-instrumentation-botocore==0.46b0.dev",
    # },
    # {
    #     "library": "cassandra-driver ~= 3.25",
    #     "instrumentation": "opentelemetry-instrumentation-cassandra==0.46b0.dev",
    # },
    # {
    #     "library": "scylla-driver ~= 3.25",
    #     "instrumentation": "opentelemetry-instrumentation-cassandra==0.46b0.dev",
    # },
    # {
    #     "library": "celery >= 4.0, < 6.0",
    #     "instrumentation": "opentelemetry-instrumentation-celery==0.46b0.dev",
    # },
    # {
    #     "library": "confluent-kafka >= 1.8.2, <= 2.3.0",
    #     "instrumentation": "opentelemetry-instrumentation-confluent-kafka==0.46b0.dev",
    # },
    # {
    #     "library": "django >= 1.10",
    #     "instrumentation": "opentelemetry-instrumentation-django==0.46b0.dev",
    # },
    # {
    #     "library": "elasticsearch >= 2.0",
    #     "instrumentation": "opentelemetry-instrumentation-elasticsearch==0.46b0.dev",
    # },
    # {
    #     "library": "falcon >= 1.4.1, < 3.1.2",
    #     "instrumentation": "opentelemetry-instrumentation-falcon==0.46b0.dev",
    # },
    # {
    #     "library": "fastapi ~= 0.58",
    #     "instrumentation": "opentelemetry-instrumentation-fastapi==0.46b0.dev",
    # },
    # {
    #     "library": "flask >= 1.0",
    #     "instrumentation": "opentelemetry-instrumentation-flask==0.46b0.dev",
    # },
    # {
    #     "library": "grpcio ~= 1.27",
    #     "instrumentation": "opentelemetry-instrumentation-grpc==0.46b0.dev",
    # },
    # {
    #     "library": "httpx >= 0.18.0",
    #     "instrumentation": "opentelemetry-instrumentation-httpx==0.46b0.dev",
    # },
    # {
    #     "library": "jinja2 >= 2.7, < 4.0",
    #     "instrumentation": "opentelemetry-instrumentation-jinja2==0.46b0.dev",
    # },
    # {
    #     "library": "kafka-python >= 2.0",
    #     "instrumentation": "opentelemetry-instrumentation-kafka-python==0.46b0.dev",
    # },
    # {
    #     "library": "mysql-connector-python ~= 8.0",
    #     "instrumentation": "opentelemetry-instrumentation-mysql==0.46b0.dev",
    # },
    # {
    #     "library": "mysqlclient < 3",
    #     "instrumentation": "opentelemetry-instrumentation-mysqlclient==0.46b0.dev",
    # },
    # {
    #     "library": "pika >= 0.12.0",
    #     "instrumentation": "opentelemetry-instrumentation-pika==0.46b0.dev",
    # },
    # {
    #     "library": "psycopg >= 3.1.0",
    #     "instrumentation": "opentelemetry-instrumentation-psycopg==0.46b0.dev",
    # },
    # {
    #     "library": "psycopg2 >= 2.7.3.1",
    #     "instrumentation": "opentelemetry-instrumentation-psycopg2==0.46b0.dev",
    # },
    # {
    #     "library": "pymemcache >= 1.3.5, < 5",
    #     "instrumentation": "opentelemetry-instrumentation-pymemcache==0.46b0.dev",
    # },
    # {
    #     "library": "pymongo >= 3.1, < 5.0",
    #     "instrumentation": "opentelemetry-instrumentation-pymongo==0.46b0.dev",
    # },
    # {
    #     "library": "PyMySQL < 2",
    #     "instrumentation": "opentelemetry-instrumentation-pymysql==0.46b0.dev",
    # },
    # {
    #     "library": "pyramid >= 1.7",
    #     "instrumentation": "opentelemetry-instrumentation-pyramid==0.46b0.dev",
    # },
    # {
    #     "library": "redis >= 2.6",
    #     "instrumentation": "opentelemetry-instrumentation-redis==0.46b0.dev",
    # },
    # {
    #     "library": "remoulade >= 0.50",
    #     "instrumentation": "opentelemetry-instrumentation-remoulade==0.46b0.dev",
    # },
    # {
    #     "library": "requests ~= 2.0",
    #     "instrumentation": "opentelemetry-instrumentation-requests==0.46b0.dev",
    # },
    # {
    #     "library": "scikit-learn ~= 0.24.0",
    #     "instrumentation": "opentelemetry-instrumentation-sklearn==0.46b0.dev",
    # },
    # {
    #     "library": "sqlalchemy",
    #     "instrumentation": "opentelemetry-instrumentation-sqlalchemy==0.46b0.dev",
    # },
    # {
    #     "library": "starlette ~= 0.13.0",
    #     "instrumentation": "opentelemetry-instrumentation-starlette==0.46b0.dev",
    # },
    # {
    #     "library": "psutil >= 5",
    #     "instrumentation": "opentelemetry-instrumentation-system-metrics==0.46b0.dev",
    # },
    # {
    #     "library": "tornado >= 5.1.1",
    #     "instrumentation": "opentelemetry-instrumentation-tornado==0.46b0.dev",
    # },
    # {
    #     "library": "tortoise-orm >= 0.17.0",
    #     "instrumentation": "opentelemetry-instrumentation-tortoiseorm==0.46b0.dev",
    # },
    # {
    #     "library": "pydantic >= 1.10.2",
    #     "instrumentation": "opentelemetry-instrumentation-tortoiseorm==0.46b0.dev",
    # },
    # {
    #     "library": "urllib3 >= 1.0.0, < 3.0.0",
    #     "instrumentation": "opentelemetry-instrumentation-urllib3==0.46b0.dev",
    # },
]
default_instrumentations = [
    # "opentelemetry-instrumentation-asyncio==0.46b0.dev",
    # "opentelemetry-instrumentation-aws-lambda==0.46b0.dev",
    # "opentelemetry-instrumentation-dbapi==0.46b0.dev",
    # "opentelemetry-instrumentation-logging==0.46b0.dev",
    # "opentelemetry-instrumentation-sqlite3==0.46b0.dev",
    # "opentelemetry-instrumentation-urllib==0.46b0.dev",
    # "opentelemetry-instrumentation-wsgi==0.46b0.dev",
]

install_packages = [
    "aliyun-instrumentation-dashscope",
    "aliyun-instrumentation-langchain",
    "aliyun-instrumentation-llama-index",
    "aliyun-instrumentation-openai",
    "aliyun-instrumentation-dify",
    "aliyun-opentelemetry-instrumentation",
    "aliyun-opentelemetry-instrumentation-aiohttp-client",
    "aliyun-opentelemetry-instrumentation-asgi",
    "aliyun-opentelemetry-instrumentation-django",
    "aliyun-opentelemetry-instrumentation-fastapi",
    "aliyun-opentelemetry-instrumentation-flask",
    "aliyun-opentelemetry-instrumentation-requests",
    "aliyun-opentelemetry-instrumentation-wsgi",
    "aliyun-opentelemetry-semantic-conventions",
    "aliyun-opentelemetry-util-http",
    "aliyun-sdk-extension-arms",
    "aliyun-semantic-conventions",
    "opentelemetry-instrumentation-extension-alibaba",
    "aliyun-opentelemetry-sdk",
    "aliyun-opentelemetry-instrumentation-redis",
    "aliyun-opentelemetry-instrumentation-sqlalchemy",
    "aliyun-opentelemetry-instrumentation-threading",
    "aliyun-opentelemetry-instrumentation-httpx",
    "aliyun-opentelemetry-exporter-otlp-proto-common",
    "aliyun-opentelemetry-exporter-otlp-proto-grpc",
    "aliyun-opentelemetry-exporter-otlp-proto-http",
    "aliyun-opentelemetry-proto",
    "aliyun-opentelemetry-instrumentation-logging",
    "aliyun-instrumentation-vllm",
    "aliyun-instrumentation-sglang",
    "aliyun-instrumentation-google-adk",
    "aliyun-instrumentation-mcp",
    "aliyun-opentelemetry-instrumentation-aio-pika",
    "aliyun-opentelemetry-instrumentation-aiohttp-server",
    "aliyun-opentelemetry-instrumentation-aiokafka",
    "aliyun-opentelemetry-instrumentation-aiopg",
    "aliyun-opentelemetry-instrumentation-asyncio",
    "aliyun-opentelemetry-instrumentation-asyncpg",
    "aliyun-opentelemetry-instrumentation-cassandra",
    "aliyun-opentelemetry-instrumentation-celery",
    "aliyun-opentelemetry-instrumentation-click",
    "aliyun-opentelemetry-instrumentation-confluent-kafka",
    "aliyun-opentelemetry-instrumentation-dbapi",
    "aliyun-opentelemetry-instrumentation-elasticsearch",
    "aliyun-opentelemetry-instrumentation-falcon",
    "aliyun-opentelemetry-instrumentation-grpc",
    "aliyun-opentelemetry-instrumentation-jinja2",
    "aliyun-opentelemetry-instrumentation-kafka-python",
    "aliyun-opentelemetry-instrumentation-mysql",
    "aliyun-opentelemetry-instrumentation-mysqlclient",
    "aliyun-opentelemetry-instrumentation-pika",
    "aliyun-opentelemetry-instrumentation-psycopg",
    "aliyun-opentelemetry-instrumentation-psycopg2",
    "aliyun-opentelemetry-instrumentation-pymemcache",
    "aliyun-opentelemetry-instrumentation-pymongo",
    "aliyun-opentelemetry-instrumentation-pymssql",
    "aliyun-opentelemetry-instrumentation-pymysql",
    "aliyun-opentelemetry-instrumentation-pyramid",
    "aliyun-opentelemetry-instrumentation-remoulade",
    "aliyun-opentelemetry-instrumentation-sqlite3",
    "aliyun-opentelemetry-instrumentation-starlette",
    "aliyun-opentelemetry-instrumentation-tornado",
    "aliyun-opentelemetry-instrumentation-tortoiseorm",
    "aliyun-opentelemetry-instrumentation-urllib",
    "aliyun-opentelemetry-instrumentation-urllib3",
    "aliyun-instrumentation-dify-plugin",
    "aliyun-opentelemetry-instrumentation-milvus",
    "aliyun-util-genai",
]
